# Autogenerated by Astropy-affiliated package astropy_helpers's setup.py on 2018-02-09 16:46:16
from __future__ import unicode_literals
import datetime

version = "3.0"
githash = "b7fc50081b55d46da118bbf7c2fce5cad8350b0e"


major = 3
minor = 0
bugfix = 0

release = True
timestamp = datetime.datetime(2018, 2, 9, 16, 46, 16)
debug = False

try:
    from ._compiler import compiler
except ImportError:
    compiler = "unknown"

try:
    from .cython_version import cython_version
except ImportError:
    cython_version = "unknown"
